@@ -4,9 +4,9 @@ use holochain_cascade::test_utils::*;
 use holochain_cascade::Cascade;
 use holochain_p2p::MockHolochainP2pDnaT;
 use holochain_state::mutations::insert_op_scratch;
-use holochain_state::prelude::test_authored_env;
-use holochain_state::prelude::test_cache_env;
-use holochain_state::prelude::test_dht_env;
+use holochain_state::prelude::test_authored_db;
+use holochain_state::prelude::test_cache_db;
+use holochain_state::prelude::test_dht_db;
 use holochain_state::scratch::Scratch;
 use holochain_types::link::WireLinkOps;
 use holochain_zome_types::ChainTopOrdering;
@@ -17,19 +17,19 @@ async fn links_not_authority() {
     observability::test_run().ok();
 
     // Environments
-    let cache = test_cache_env();
-    let authority = test_dht_env();
+    let cache = test_cache_db();
+    let authority = test_dht_db();
 
     // Data
     let td = EntryTestData::create();
-    fill_db(&authority.env(), td.store_entry_op.clone());
-    fill_db(&authority.env(), td.create_link_op.clone());
+    fill_db(&authority.to_db(), td.store_entry_op.clone());
+    fill_db(&authority.to_db(), td.create_link_op.clone());
 
     // Network
-    let network = PassThroughNetwork::authority_for_nothing(vec![authority.env().clone().into()]);
+    let network = PassThroughNetwork::authority_for_nothing(vec![authority.to_db().clone().into()]);
 
     // Cascade
-    let mut cascade = Cascade::empty().with_network(network, cache.env());
+    let mut cascade = Cascade::empty().with_network(network, cache.to_db());
 
     let r = cascade
         .dht_get_links(td.link_key_tag.clone(), Default::default())
@@ -45,7 +45,7 @@ async fn links_not_authority() {
 
     assert_eq!(r, vec![(td.create_link_header.clone(), vec![]),]);
 
-    fill_db(&authority.env(), td.delete_link_op.clone());
+    fill_db(&authority.to_db(), td.delete_link_op.clone());
 
     let r = cascade
         .dht_get_links(td.link_key.clone(), Default::default())
@@ -73,13 +73,13 @@ async fn links_authority() {
     observability::test_run().ok();
 
     // Environments
-    let cache = test_cache_env();
-    let vault = test_authored_env();
+    let cache = test_cache_db();
+    let vault = test_authored_db();
 
     // Data
     let td = EntryTestData::create();
-    fill_db(&vault.env(), td.store_entry_op.clone());
-    fill_db(&vault.env(), td.create_link_op.clone());
+    fill_db(&vault.to_db(), td.store_entry_op.clone());
+    fill_db(&vault.to_db(), td.create_link_op.clone());
 
     // Network
     // - Not expecting any calls to the network.
@@ -89,8 +89,8 @@ async fn links_authority() {
 
     // Cascade
     let mut cascade = Cascade::empty()
-        .with_network(mock, cache.env())
-        .with_authored(vault.env().into());
+        .with_network(mock, cache.to_db())
+        .with_authored(vault.to_db().into());
 
     let r = cascade
         .dht_get_links(td.link_key_tag.clone(), Default::default())
@@ -99,7 +99,7 @@ async fn links_authority() {
 
     assert_eq!(r, td.links);
 
-    fill_db(&vault.env(), td.delete_link_op.clone());
+    fill_db(&vault.to_db(), td.delete_link_op.clone());
 
     let r = cascade
         .dht_get_links(td.link_key.clone(), Default::default())
@@ -114,7 +114,7 @@ async fn links_authoring() {
     observability::test_run().ok();
 
     // Environments
-    let cache = test_cache_env();
+    let cache = test_cache_db();
     let mut scratch = Scratch::new();
     let zome = fixt!(Zome);
 
@@ -149,7 +149,7 @@ async fn links_authoring() {
 
     // Cascade
     let mut cascade = Cascade::empty()
-        .with_network(mock.clone(), cache.env())
+        .with_network(mock.clone(), cache.to_db())
         .with_scratch(scratch.clone().into_sync());
 
     let r = cascade
@@ -168,7 +168,7 @@ async fn links_authoring() {
     .unwrap();
 
     let mut cascade = Cascade::empty()
-        .with_network(mock, cache.env())
+        .with_network(mock, cache.to_db())
         .with_scratch(scratch.into_sync());
 
     let r = cascade
